/************************************************************************************************

 Author        : ADI - Apps            www.analog.com

 Date          : Julu 2009

 File          : PWM.c

 Hardware      : ADuC7122

 Description   : This simple example shows how to use the PWM.
*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000
#define BIT16 0x10000
#define BIT17 0x20000
#define BIT18 0x40000
#define BIT19 0x80000
#define BIT20 0x100000
#define BIT23 0x800000
#define BIT24 0x1000000

 
#include <Analogdevices\ioADuC7122.H>
#include <intrinsics.h>

void ConfigurePWM(void);

unsigned char bTripDetected = 0;
int main(void)
{

        POWKEY1 = 0x1;
	POWCON = 0x02;		   	// Set core to max CPU speed of 10.24Mhz
	POWKEY2 = 0xF4;
	
	// Initialize the GPIO pins for PWM mode
	GP1CON = BIT16+BIT20;  		// Select PWM1 and PWM2 output
	GP3CON  = BIT8 + BIT12; 	// Select PWM3, PWM4 output
	GP2CON  = BIT16 + BIT20; 	// Select PWM5 and PWM6	output
	PWMCON1	= BIT0 + BIT10+ BIT7; 	// PWM Standard mode, UCLK/4, PWM Trip interrupt enabled	
        __enable_interrupt();
	
	ConfigurePWM();			// Call function to configure PWM
	bTripDetected = 0;
	IRQEN	= BIT23;	 	// Enable PWM Trip interrupt source
	while (1)
	{
	   if (bTripDetected == 1)
	    {
	   	bTripDetected = 0;
	   	ConfigurePWM();
	    }
	}
}

__irq void IRQ_Handler(void)   		// Unused in this application
{
   unsigned long IRQSTATUS = 0;

   IRQSTATUS = IRQSTA;	   	        // Read off IRQSTA register

   if ((IRQSTATUS & BIT23) == BIT23)    // If PWM trip interrupt source
   {
      bTripDetected = 1;		// Set flag to re configure the PWM block
      PWMCLRI = 0xFF;		        // Clear the PWM trip interrupt source
   }
}
        
void ConfigurePWM(void)
{
   //Configure PWM2 for 20khz duty cycle
   // P1.5
	PWM1COM1 = 0x80;	        //	Configure PWM1 output high trigger time
	PWM1COM2 = 0xFF;	        //	Configure PWM1 output Low trigger time
	PWM1COM3=  0x80;	        //	Configure PWM2 output low trigger time
	PWM1LEN =  0xFF;	        //	Configure PWM2 output high trigger time

	//Configure PWM4 for 10khz duty cycle
	// P3.3
	PWM2COM1 = 0xFF;		//	Configure PWM3 output high trigger time
	PWM2COM2 = 0x1FF;		//	Configure PWM3 output Low trigger time
	PWM2COM3 = 0xFF;		//	Configure PWM4 output low trigger time
	PWM2LEN = 0x1FF;		//	Configure PWM4 output high trigger time

	//Configure PWM6 for 40khz duty cycle
	// P2.6
	PWM3COM1 = 0x40;		//	Configure PWM5 output high trigger time
	PWM3COM2 = 0x80;		//	Configure PWM5 output Low trigger time
	PWM3COM3 = 0x40;		//	Configure PWM6 output low trigger time
	PWM3LEN = 0x80;		        //	Configure PWM6 output high trigger time
}

